@@ -3,11 +3,11 @@ from python_framework import Controller, ControllerMethod, HttpStatus
 from enumeration.AccessDomain import AccessDomain
 
 
-@Controller(url = '/api/memory', tag='Memory', description='Memory controller')
+@Controller(url = '/memory', tag='Memory', description='Memory controller')
 class MemoryController:
 
-    @ControllerMethod(url = '/'
-        # apiKey = [AccessDomain.API],
+    @ControllerMethod(url = '/',
+        apiKeyRequired = [AccessDomain.ADMIN]
         # requestClass = [MessageDto.MessageRequestDto]
         # responseClass = [MessageDto.MessageResponseDto]
         # responseClass = [MessageDto.MessageRequestDto]
